@@ -1,7 +1,9 @@
+# -*- coding: utf-8 -*-
 import os
 import fido
 
-from email.utils import formataddr, parseaddr
+from pyisemail import is_email
+from pyisemail.diagnosis import BaseDiagnosis
 from swagger_spec_validator.common import SwaggerValidationError
 from bravado_core.formatter import SwaggerFormat
 from bravado.client import SwaggerClient
@@ -10,20 +12,23 @@ from bravado.http_future import HttpFuture
 from bravado.swagger_model import Loader
 
 
-HOST = os.environ.get('MPCONTRIBS_API_HOST', 'api.mpcontribs.org')
+DEFAULT_HOST = "api.mpcontribs.org"
+HOST = os.environ.get("MPCONTRIBS_API_HOST", DEFAULT_HOST)
 client = None
 
 
 def validate_email(email_string):
-    try:
-        formataddr(parseaddr(email_string))
-    except Exception as ex:
-        raise SwaggerValidationError(f'E-mail {email_string} is invalid')
+    d = is_email(email_string, diagnose=True)
+    if d > BaseDiagnosis.CATEGORIES["VALID"]:
+        raise SwaggerValidationError(f"{email_string} {d.message}")
 
 
 email_format = SwaggerFormat(
-    format='email', to_wire=str, to_python=str,
-    validate=validate_email, description='e-mail address'
+    format="email",
+    to_wire=str,
+    to_python=str,
+    validate=validate_email,
+    description="e-mail address",
 )
 
 
@@ -34,9 +39,11 @@ class FidoClientGlobalHeaders(FidoClient):
 
     def request(self, request_params, operation=None, request_config=None):
         request_for_twisted = self.prepare_request_for_twisted(request_params)
-        request_for_twisted['headers'].update(self.headers)
+        request_for_twisted["headers"].update(self.headers)
         future_adapter = self.future_adapter_class(fido.fetch(**request_for_twisted))
-        return HttpFuture(future_adapter, self.response_adapter_class, operation, request_config)
+        return HttpFuture(
+            future_adapter, self.response_adapter_class, operation, request_config
+        )
 
 
 def load_client(apikey=None, headers=None, host=HOST):
@@ -50,19 +57,24 @@ def load_client(apikey=None, headers=None, host=HOST):
     if force or client is None:
         # - Kong forwards consumer headers when api-key used for auth
         # - forward consumer headers when connecting through localhost
-        headers = {'x-api-key': apikey} if apikey else headers
+        headers = {"x-api-key": apikey} if apikey else headers
         http_client = FidoClientGlobalHeaders(headers=headers)
         loader = Loader(http_client)
-        protocol = 'https' if apikey else 'http'
-        spec_url = f'{protocol}://{host}/apispec.json'
+        protocol = "https" if apikey else "http"
+        spec_url = f"{protocol}://{host}/apispec.json"
         spec_dict = loader.load_spec(spec_url)
-        spec_dict['host'] = host
-        spec_dict['schemes'] = [protocol]
+        spec_dict["host"] = host
+        spec_dict["schemes"] = [protocol]
         client = SwaggerClient.from_spec(
-            spec_dict, spec_url, http_client, {
-                'validate_responses': False, 'use_models': False,
-                'include_missing_properties': False, 'formats': [email_format]
-            }
+            spec_dict,
+            spec_url,
+            http_client,
+            {
+                "validate_responses": False,
+                "use_models": False,
+                "include_missing_properties": False,
+                "formats": [email_format],
+            },
         )
 
     return client
